Class: Google::Api::BatchingSettingsProto
- Inherits:
-
Object
- Object
- Google::Api::BatchingSettingsProto
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/api/client.rb
Overview
BatchingSettingsProto specifies a set of batching thresholds, each of
which acts as a trigger to send a batch of messages as a request. At least
one threshold must be positive nonzero.
Instance Attribute Summary collapse
-
#delay_threshold ⇒ ::Google::Protobuf::Duration
The duration after which a batch should be sent, starting from the addition of the first message to that batch.
-
#element_count_limit ⇒ ::Integer
The maximum number of elements collected in a batch that could be accepted by server.
-
#element_count_threshold ⇒ ::Integer
The number of elements of a field collected into a batch which, if exceeded, causes the batch to be sent.
-
#flow_control_byte_limit ⇒ ::Integer
The maximum size of data allowed by flow control.
-
#flow_control_element_limit ⇒ ::Integer
The maximum number of elements allowed by flow control.
-
#flow_control_limit_exceeded_behavior ⇒ ::Google::Api::FlowControlLimitExceededBehaviorProto
The behavior to take when the flow control limit is exceeded.
-
#request_byte_limit ⇒ ::Integer
The maximum size of the request that could be accepted by server.
-
#request_byte_threshold ⇒ ::Integer
The aggregated size of the batched field which, if exceeded, causes the batch to be sent.
Instance Attribute Details
#delay_threshold ⇒ ::Google::Protobuf::Duration
Returns The duration after which a batch should be sent, starting from the addition of the first message to that batch.
505 506 507 508 |
# File 'proto_docs/google/api/client.rb', line 505 class BatchingSettingsProto include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#element_count_limit ⇒ ::Integer
Returns The maximum number of elements collected in a batch that could be accepted by server.
505 506 507 508 |
# File 'proto_docs/google/api/client.rb', line 505 class BatchingSettingsProto include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#element_count_threshold ⇒ ::Integer
Returns The number of elements of a field collected into a batch which, if exceeded, causes the batch to be sent.
505 506 507 508 |
# File 'proto_docs/google/api/client.rb', line 505 class BatchingSettingsProto include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#flow_control_byte_limit ⇒ ::Integer
Returns The maximum size of data allowed by flow control.
505 506 507 508 |
# File 'proto_docs/google/api/client.rb', line 505 class BatchingSettingsProto include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#flow_control_element_limit ⇒ ::Integer
Returns The maximum number of elements allowed by flow control.
505 506 507 508 |
# File 'proto_docs/google/api/client.rb', line 505 class BatchingSettingsProto include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#flow_control_limit_exceeded_behavior ⇒ ::Google::Api::FlowControlLimitExceededBehaviorProto
Returns The behavior to take when the flow control limit is exceeded.
505 506 507 508 |
# File 'proto_docs/google/api/client.rb', line 505 class BatchingSettingsProto include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_byte_limit ⇒ ::Integer
Returns The maximum size of the request that could be accepted by server.
505 506 507 508 |
# File 'proto_docs/google/api/client.rb', line 505 class BatchingSettingsProto include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_byte_threshold ⇒ ::Integer
Returns The aggregated size of the batched field which, if exceeded, causes the batch to be sent. This size is computed by aggregating the sizes of the request field to be batched, not of the entire request message.
505 506 507 508 |
# File 'proto_docs/google/api/client.rb', line 505 class BatchingSettingsProto include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |