Class: Google::Cloud::Metastore::V1beta::ScalingConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Metastore::V1beta::ScalingConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/metastore/v1beta/metastore.rb
Overview
Represents the scaling configuration of a metastore service.
Defined Under Namespace
Modules: InstanceSize
Instance Attribute Summary collapse
-
#instance_size ⇒ ::Google::Cloud::Metastore::V1beta::ScalingConfig::InstanceSize
An enum of readable instance sizes, with each instance size mapping to a float value (e.g. InstanceSize.EXTRA_SMALL = scaling_factor(0.1)).
-
#scaling_factor ⇒ ::Float
Scaling factor, increments of 0.1 for values less than 1.0, and increments of 1.0 for values greater than 1.0.
Instance Attribute Details
#instance_size ⇒ ::Google::Cloud::Metastore::V1beta::ScalingConfig::InstanceSize
Returns An enum of readable instance sizes, with each instance size mapping to a float value (e.g. InstanceSize.EXTRA_SMALL = scaling_factor(0.1))
Note: The following fields are mutually exclusive: instance_size, scaling_factor. If a field in that set is populated, all other fields in the set will automatically be cleared.
723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 |
# File 'proto_docs/google/cloud/metastore/v1beta/metastore.rb', line 723 class ScalingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Metastore instance sizes. module InstanceSize # Unspecified instance size INSTANCE_SIZE_UNSPECIFIED = 0 # Extra small instance size, maps to a scaling factor of 0.1. EXTRA_SMALL = 1 # Small instance size, maps to a scaling factor of 0.5. SMALL = 2 # Medium instance size, maps to a scaling factor of 1.0. MEDIUM = 3 # Large instance size, maps to a scaling factor of 3.0. LARGE = 4 # Extra large instance size, maps to a scaling factor of 6.0. EXTRA_LARGE = 5 end end |
#scaling_factor ⇒ ::Float
Returns Scaling factor, increments of 0.1 for values less than 1.0, and increments of 1.0 for values greater than 1.0.
Note: The following fields are mutually exclusive: scaling_factor, instance_size. If a field in that set is populated, all other fields in the set will automatically be cleared.
723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 |
# File 'proto_docs/google/cloud/metastore/v1beta/metastore.rb', line 723 class ScalingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Metastore instance sizes. module InstanceSize # Unspecified instance size INSTANCE_SIZE_UNSPECIFIED = 0 # Extra small instance size, maps to a scaling factor of 0.1. EXTRA_SMALL = 1 # Small instance size, maps to a scaling factor of 0.5. SMALL = 2 # Medium instance size, maps to a scaling factor of 1.0. MEDIUM = 3 # Large instance size, maps to a scaling factor of 3.0. LARGE = 4 # Extra large instance size, maps to a scaling factor of 6.0. EXTRA_LARGE = 5 end end |